#include "UtilString.hh"

#include <sstream>
#include <limits>


// Transforme une chaine en liste de tokens
std::vector< std::string > Tokenize( const std::string & str ,
				     const std::string & delim ) 
{
  std::vector< std::string > res ;

  // Enleve les delimiteurs au debut
  std::string::size_type last = str.find_first_not_of( delim , 0 ) ;
  
  // Trouve le premier non delimiteur 
  std::string::size_type cur = str.find_first_of( delim , last ) ;

  while( cur != std::string::npos ||
	 last != std::string::npos )
    {
      res.push_back( str.substr( last , cur - last ) ) ;
      
      // Zappe les delimiteurs 
      last = str.find_first_not_of( delim , cur ) ;
      
      // Trouve le prochain non delimiteur
      cur = str.find_first_of( delim , last ) ;
    }

  return res ;
}


// Conversion d'un string en flotant 
float ToFloat( const std::string & str ) 
{
  float res ;
  std::istringstream iss( str ) ;

  iss >> res ;
  
  // Detecte une erreur eventuelle 
  if( iss.fail() )
    return std::numeric_limits< float >::max() ;

  return res ;
}

double ToDouble( const std::string & str ) 
{
  double res ;
  std::istringstream iss( str ) ;

  iss >> res ;
  
  // Detecte une erreur eventuelle 
  if( iss.fail() )
    return std::numeric_limits< double >::max() ;

  return res ;
}

size_t ToSizeT( const std::string & str ) 
{
  size_t res ;
  std::istringstream iss( str ) ;

  iss >> res ;
  
  // Detecte une erreur eventuelle 
  if( iss.fail() )
    return std::numeric_limits< size_t >::max() ;

  return res ;  
}

unsigned long ToULong( const std::string & str ) 
{
  unsigned long res ;
  std::istringstream iss( str ) ;

  iss >> res ;
  
  // Detecte une erreur eventuelle 
  if( iss.fail() )
    return std::numeric_limits< unsigned long >::max() ;

  return res ;
}
