#include <iostream>
#include <cstdlib>
#include <fstream>
#include <string>

#include "UtilString.hh"

void usage( const char * argn )
{
  std::cerr << "Usage :" << std::endl ; 
  std::cerr << "   " << argn << "bundle.out" << "file.ply" << std::endl ;
  exit( EXIT_FAILURE ) ;
}

void process_file( const char * const file_in , 
		   const char * const file_out )
{
  std::ifstream input( file_in ) ;
  std::ofstream output( file_out ) ;

  bool OkParam = false ;

  unsigned long nb_pts ;
  unsigned long nb_cam ;
  
  while( ! OkParam )
    {
      std::string line ;
      getline( input , line ) ;

      if( line.size() == 0 )
	continue ;

      if( line[0] == '#' )
	continue ;
      
      const std::vector< std::string > tokens = Tokenize( line , " \r\n" ) ;
      
      nb_cam = ToULong( tokens[0] ) ;
      nb_pts = ToULong( tokens[1] ) ;
      OkParam = true ;
    }
  
  // Ecriture de l'entete du fichier
  output << "ply" << std::endl ;
  output << "format ascii 1.0" << std::endl ;
  output << "element vertex " << nb_pts <<  std::endl ;
  output << "property float x" << std::endl ;
  output << "property float y" << std::endl ;
  output << "property float z" << std::endl ;
  output << "property uchar diffuse_red" << std::endl ;
  output << "property uchar diffuse_green" << std::endl ;
  output << "property uchar diffuse_blue" << std::endl ;
  output << "end_header" << std::endl ;

  // Skip camera entry
  for( unsigned long i = 0 ; i < nb_cam ; ++i )
    {
      std::string line ;
      
      // focal dx dy 
      getline( input , line ) ;
      
      // Rotation matrix 
      getline( input , line ) ;
      getline( input , line ) ;
      getline( input , line ) ;

      // Translation Vector
      getline( input , line ) ;
    }

  // Traitement des points
  for( unsigned long i = 0 ; i < nb_pts ; ++i )
    {
      std::string line ;
      
      // Position vector 
      getline( input , line ) ;
      std::vector< std::string > tok_pos = Tokenize( line , " \r\t\n" ) ;
      output << tok_pos[0] << " " << tok_pos[1] << " " << tok_pos[2] << " " ;
            
      // Color       
      getline( input , line ) ;
      std::vector< std::string > tok_col = Tokenize( line , " \r\t\n" ) ;
      output << tok_col[0] << " " << tok_col[1] << " " << tok_col[2] << std::endl ;

      // View List 
      getline( input , line ) ;
    }

  input.close() ;
  output.close() ;
}

int main( int argc , char ** argv )
{
  if( argc != 3 )
    {
      usage( argv[0] ) ;
    }

  process_file( argv[1] , argv[2] ) ;
  
  return EXIT_SUCCESS ;
}
